@@ -45,41 +45,44 @@ from .types import Sentinel, UNLIMITED, ByteOrder
 @runtime_checkable
 class BufferFactory(Protocol): # pragma: no cover
     "BufferFactory Protocol definition"
-    def create(self, init_or_size: Union[int, bytes], size: int = None) -> Any:
+    def create(self, init_or_size: Union[int, bytes], size: int=None) -> Any:
         """This function must create and return a mutable character buffer.
 
-Arguments:
-    init_or_size: Must be an integer which specifies the size of the array, or a bytes
-        object which will be used to initialize the array items.
-    size: Size of the array.
-"""
-    def clear(self, buffer: Any) -> None:
-        """Fills the buffer with zero.
-
-Argument:
-    buffer: A memory buffer previously created by `BufferFactory.create()` method.
-"""
-
-class BytesBufferFactory:
-    """Buffer factory for `bytearray` buffers."""
-    def create(self, init_or_size: Union[int, bytes], size: int = None) -> bytearray:
-        """This function creates a mutable character buffer. The returned object is a `bytearray`.
-
     Arguments:
         init_or_size: Must be an integer which specifies the size of the array, or a bytes
             object which will be used to initialize the array items.
         size: Size of the array.
-
-    Important:
-        Although arguments are the same as for `ctypes.create_string_buffer`, the behavior
-        is different when new buffer is initialized from bytes:
-
-        1. If there are more bytes than specified `size`, this function copies only `size`
-           bytes into new buffer. The `~ctypes.create_string_buffer` raises an excpetion.
-        2. Unlike `~ctypes.create_string_buffer` when `size` is NOT specified, the buffer
-           is NOT made one item larger than its length so that the last element in the array
-           is a NUL termination character.
     """
+    def clear(self, buffer: Any) -> None:
+        """Fills the buffer with zero.
+
+    Argument:
+        buffer: A memory buffer previously created by `BufferFactory.create()` method.
+    """
+
+class BytesBufferFactory:
+    """Buffer factory for `bytearray` buffers.
+    """
+    def create(self, init_or_size: Union[int, bytes], size: int=None) -> bytearray:
+        """This function creates a mutable character buffer. The returned object is a
+        `bytearray`.
+
+        Arguments:
+            init_or_size: Must be an integer which specifies the size of the array,
+                or a bytes object which will be used to initialize the array items.
+            size: Size of the array.
+
+        Important:
+            Although arguments are the same as for `ctypes.create_string_buffer`,
+            the behavior is different when new buffer is initialized from bytes:
+
+            1. If there are more bytes than specified `size`, this function copies only
+               `size` bytes into new buffer. The `~ctypes.create_string_buffer` raises
+               an excpetion.
+            2. Unlike `~ctypes.create_string_buffer` when `size` is NOT specified,
+               the buffer is NOT made one item larger than its length so that the last
+               element in the array is a NUL termination character.
+        """
         if isinstance(init_or_size, int):
             return bytearray(init_or_size)
         size = len(init_or_size) if size is None else size
@@ -88,30 +91,32 @@ class BytesBufferFactory:
         buffer[:limit] = init_or_size[:limit]
         return buffer
     def clear(self, buffer: bytearray) -> None:
-        "Fills the buffer with zero"
+        "Fills the buffer with zero."
         buffer[:] = b'\x00' * len(buffer)
 
 class CTypesBufferFactory:
-    """Buffer factory for `ctypes` array of `~ctypes.c_char` buffers."""
-    def create(self, init_or_size: Union[int, bytes], size: int = None) -> bytearray:
+    """Buffer factory for `ctypes` array of `~ctypes.c_char` buffers.
+    """
+    def create(self, init_or_size: Union[int, bytes], size: int=None) -> bytearray:
         """This function creates a `ctypes` mutable character buffer. The returned object
-is an array of `ctypes.c_char`.
+        is an array of `ctypes.c_char`.
 
-Arguments:
-    init_or_size: Must be an integer which specifies the size of the array, or a bytes
-        object which will be used to initialize the array items.
-    size: Size of the array.
+        Arguments:
+            init_or_size: Must be an integer which specifies the size of the array,
+                or a bytes object which will be used to initialize the array items.
+            size: Size of the array.
 
-Important:
-    Although arguments are the same as for `ctypes.create_string_buffer`, the behavior
-    is different when new buffer is initialized from bytes:
+        Important:
+            Although arguments are the same as for `ctypes.create_string_buffer`,
+            the behavior is different when new buffer is initialized from bytes:
 
-    1. If there are more bytes than specified `size`, this function copies only `size`
-       bytes into new buffer. The `~ctypes.create_string_buffer` raises an excpetion.
-    2. Unlike `~ctypes.create_string_buffer` when `size` is NOT specified, the buffer is NOT
-       made one item larger than its length so that the last element in the array is a
-       NUL termination character.
-"""
+            1. If there are more bytes than specified `size`, this function copies only
+               `size` bytes into new buffer. The `~ctypes.create_string_buffer` raises
+               an excpetion.
+            2. Unlike `~ctypes.create_string_buffer` when `size` is NOT specified,
+               the buffer is NOT made one item larger than its length so that the last
+               element in the array is a NUL termination character.
+        """
         if isinstance(init_or_size, int):
             return create_string_buffer(init_or_size)
         size = len(init_or_size) if size is None else size
@@ -120,43 +125,42 @@ Important:
         buffer[:limit] = init_or_size[:limit]
         return buffer
     def clear(self, buffer: bytearray, init: int=0) -> None:
-        "Fills the buffer with specified value (default)"
+        "Fills the buffer with specified value (default)."
         memset(buffer, init, len(buffer))
 
 def safe_ord(byte: Union[bytes, int]) -> int:
-    """If `byte` argument is byte character, returns ord(byte), otherwise returns argument."""
+    """If `byte` argument is byte character, returns ord(byte), otherwise returns argument.
+    """
     return byte if isinstance(byte, int) else ord(byte)
 
 class MemoryBuffer:
     """Generic memory buffer manager.
-
-Arguments:
-    init: Must be an integer which specifies the size of the array, or a `bytes` object
-          which will be used to initialize the array items.
-    size: Size of the array. The argument value is used only when `init` is a `bytes` object.
-    factory: Factory object used to create/resize the internal memory buffer.
-    eof_marker: Value that indicates the end of data. Could be None.
-    max_size: If specified, the buffer couldn't grow beyond specified number of bytes.
-    byteorder: The byte order used to read/write numbers.
-
-Attributes:
-    raw: The memory buffer. The actual data type of buffer depends on `buffer factory`, but
-         it must provide direct acces to cells, slices and length like `bytearray`.
-    pos (int): Current position in buffer, i.e. the next read/writen byte would be at this position.
-    factory (BufferFactory): Buffer factory instance used by manager [default: `BytesBufferFactory`].
-    eof_marker (int): Value that indicates the end of data. Could be None.
-    max_size (int or `.UNLIMITED`): The buffer couldn't grow beyond specified number of bytes
-      [default: `.UNLIMITED`].
-    byteorder (ByteOrder): The byte order used to read/write numbers [default: `.LITTLE`].
-"""
+    """
     def __init__(self, init: Union[int, bytes], size: int = None, *,
-                 factory: Type[BufferFactory]=BytesBufferFactory, eof_marker: int=None,
+                 factory: Type[BufferFactory]=BytesBufferFactory, eof_marker: int = None,
                  max_size: Union[int, Sentinel]=UNLIMITED, byteorder: ByteOrder=ByteOrder.LITTLE):
+        """
+        Arguments:
+            init: Must be an integer which specifies the size of the array, or a `bytes` object
+                  which will be used to initialize the array items.
+            size: Size of the array. The argument value is used only when `init` is a `bytes` object.
+            factory: Factory object used to create/resize the internal memory buffer.
+            eof_marker: Value that indicates the end of data. Could be None.
+            max_size: If specified, the buffer couldn't grow beyond specified number of bytes.
+            byteorder: The byte order used to read/write numbers.
+        """
+        #: Buffer factory instance used by manager [default: `BytesBufferFactory`].
         self.factory: BufferFactory = factory()
+        #: The memory buffer. The actual data type of buffer depends on `buffer factory`,
+        #: but it must provide direct acces to cells, slices and length like `bytearray`.
         self.raw: bytearray = self.factory.create(init, size)
+        #: Current position in buffer, i.e. the next read/writen byte would be at this position.
         self.pos: int = 0
+        #: Value that indicates the end of data. Could be None.
         self.eof_marker: int = eof_marker
+        #: The buffer couldn't grow beyond specified number of bytes [default: `.UNLIMITED`].
         self.max_size: Union[int, Sentinel] = max_size
+        #: The byte order used to read/write numbers [default: `.LITTLE`].
         self.byteorder: ByteOrder = byteorder
     def _ensure_space(self, size: int) -> None:
         if len(self.raw) < self.pos + size:
@@ -174,41 +178,41 @@ Attributes:
             raise IOError(f"Cannot resize buffer past max. size {self.max_size} bytes")
         self.raw = self.factory.create(self.raw, size)
     def is_eof(self) -> bool:
-        "Return True when positioned past the end of buffer or on `.eof_marker` (if defined)"
+        "Return True when positioned past the end of buffer or on `.eof_marker` (if defined)."
         if self.pos >= len(self.raw):
             return True
         if self.eof_marker is not None and safe_ord(self.raw[self.pos]) == self.eof_marker:
             return True
         return False
     def write(self, data: bytes) -> None:
-        "Write bytes"
+        "Write bytes."
         size = len(data)
         self._ensure_space(size)
         self.raw[self.pos:self.pos + size] = data
         self.pos += size
     def write_byte(self, byte: int) -> None:
-        "Write byte"
+        "Write one byte."
         self._ensure_space(1)
         self.raw[self.pos] = byte
         self.pos += 1
     def write_number(self, value: int, size: int, *, signed: bool=False) -> None:
-        "Write number with specified size in bytes"
+        "Write number with specified size (in bytes)."
         self.write(value.to_bytes(size, self.byteorder.value, signed=signed))
     def write_short(self, value: int) -> None:
-        "Write 2 byte number (c_ushort)"
+        "Write 2 byte number (c_ushort)."
         self.write_number(value, 2)
     def write_int(self, value: int) -> None:
-        "Write 4 byte number (c_uint)"
+        "Write 4 byte number (c_uint)."
         self.write_number(value, 4)
     def write_bigint(self, value: int) -> None:
-        "Write tagged 8 byte number (c_ulonglong)"
+        "Write tagged 8 byte number (c_ulonglong)."
         self.write_number(value, 8)
     def write_string(self, value: str, *, encoding='ascii') -> None:
-        "Write zero-terminated string"
+        "Write zero-terminated string."
         self.write(value.encode(encoding))
         self.write_byte(0)
     def write_pascal_string(self, value: str, *, encoding='ascii') -> None:
-        "Write tagged Pascal string (2 byte length followed by data)"
+        "Write tagged Pascal string (2 byte length followed by data)."
         value = value.encode(encoding)
         size = len(value)
         self.write_byte(size)
@@ -222,28 +226,28 @@ Attributes:
         self.pos += size
         return result
     def read_number(self, size: int, *, signed=False) -> int:
-        "Read number with specified size in bytes"
+        "Read number with specified size in bytes."
         self._check_space(size)
         result = (0).from_bytes(self.raw[self.pos: self.pos + size], self.byteorder.value, signed=signed)
         self.pos += size
         return result
     def read_byte(self, *, signed=False) -> int:
-        "Read 1 byte number (c_ubyte)"
+        "Read 1 byte number (c_ubyte)."
         return self.read_number(1, signed=signed)
     def read_short(self, *, signed=False) -> int:
-        "Read 2 byte number (c_ushort)"
+        "Read 2 byte number (c_ushort)."
         return self.read_number(2, signed=signed)
     def read_int(self, *, signed=False) -> int:
-        "Read 4 byte number (c_uint)"
+        "Read 4 byte number (c_uint)."
         return self.read_number(4, signed=signed)
     def read_bigint(self, *, signed=False) -> int:
-        "Read 8 byte number (c_ulonglong)"
+        "Read 8 byte number (c_ulonglong)."
         return self.read_number(8, signed=signed)
     def read_sized_int(self, *, signed=False) -> int:
-        "Read number cluster (2 byte length followed by data)"
+        "Read number cluster (2 byte length followed by data)."
         return self.read_number(self.read_short(), signed=signed)
     def read_string(self, *, encoding='ascii') -> str:
-        "Read null-terminated string"
+        "Read null-terminated string."
         i = self.pos
         while i < self.buffer_size and safe_ord(self.raw[i]) != 0:
             i += 1
@@ -251,13 +255,13 @@ Attributes:
         self.pos += 1
         return result
     def read_pascal_string(self, *, encoding='ascii') -> str:
-        "Read Pascal string (1 byte length followed by string data)"
+        "Read Pascal string (1 byte length followed by string data)."
         return self.read(self.read_byte()).decode(encoding)
     def read_sized_string(self, *, encoding='ascii') -> str:
-        "Read string (2 byte length followed by data)"
+        "Read string (2 byte length followed by data)."
         return self.read(self.read_short()).decode(encoding)
     def read_bytes(self) -> bytes:
-        "Read content of binary cluster (2 bytes data length followed by data)"
+        "Read content of binary cluster (2 bytes data length followed by data)."
         return self.read(self.read_short())
     # Properties
     @property
